# NEXSTEM WISDOM SDK - PYTHON BINDING

## Modules

- DEVICE
- STREAM
- PREPROCESSING
- VISUALIZATION (VIZ) - In Development
- TRAINING - In Development
  - EXPERIMENT
  - MODELS
    - MI 
    - MI2
    - SSVEP
    - P300
    - FACE
    - EMOTION
    - FOCUS
- DEPLOY
